@@ -1,21 +1,39 @@
 <?php
 
 
-   // Some uses of this plugin (such as vlogin) were somehow calling the 
+   // Some uses of this plugin (such as vlogin) were somehow calling the
    // functions here before having included the functions in global.php,
-   // resulting in fatal errors when called below.  Thus, the need for 
+   // resulting in fatal errors when called below.  Thus, the need for
    // this include
    //
+
    if (defined('SM_PATH'))
    {
+
+      // in SM 1.4, we need to include the validate file first
+      // thing so we don't lose the ability to display themes,
+      // but we cannot include this file unless we are being
+      // called from a plugin request, thus this if statement
+      //
+      if ( strpos(getcwd(), 'plugins') ) 
+      {
+         if (file_exists(SM_PATH . 'include/validate.php'))
+            include_once(SM_PATH . 'include/validate.php');
+         else if (file_exists(SM_PATH . 'src/validate.php'))
+            include_once(SM_PATH . 'src/validate.php');
+      }
+
+
       include_once(SM_PATH . 'functions/strings.php');
 
+
       if (file_exists(SM_PATH . 'functions/global.php'))
          include_once(SM_PATH . 'functions/global.php');
       else if (file_exists(SM_PATH . 'src/global.php'))
-         include_once('../src/global.php');
+         include_once(SM_PATH . 'src/global.php');
+
    }
-   else 
+   else
    {
       include_once('../functions/strings.php');
 
